@@ -163,7 +163,7 @@ class FlaskJSONAPI(object):
         :param namespace: Prefix for generated endpoints
         :param route_prefix: Prefix for route patterns
         """
-        self.serializer = JSONAPI(self.sqla.Model)
+        self.serializer = JSONAPI(self.sqla.Model, prefix='{}://{}{}'.format(self.app.config['PREFERRED_URL_SCHEME'], self.app.config['SERVER_NAME'], route_prefix))
         for view in views:
             method, endpoint = view
             pattern = route_prefix + endpoint.value
