@@ -140,7 +140,7 @@ class JSONAPIResponse(object):
         self.status_code = 200
         self.data = {
             'jsonapi': {'version': '1.0'},
-            'meta': {'sqlalchemy_jsonapi_version': '4.0.1'}
+            'meta': {'sqlalchemy_jsonapi_version': '4.0.2'}
         }
 
 
@@ -980,7 +980,7 @@ class JSONAPI(object):
                         or api_key not in data['data']['relationships'].keys():
                     continue
 
-                data_rel = data['data']['relationships'][key]
+                data_rel = data['data']['relationships'][api_key]
                 if 'data' not in data_rel.keys():
                     raise BadRequestError(
                         'Missing data key in relationship {}'.format(key))
